@@ -18,6 +18,11 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
+/* Needed for the statx() calls in inline functions in glocalfileinfo.h */
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+
 #include "config.h"
 
 #include <sys/types.h>
@@ -424,7 +429,7 @@ _g_local_file_output_stream_really_close (GLocalFileOutputStream *file,
       
 #ifndef G_OS_WIN32		/* Already did the fstat() and close() above on Win32 */
 
-  if (fstat (file->priv->fd, &final_stat) == 0)
+  if (g_local_file_fstat (file->priv->fd, G_LOCAL_FILE_STAT_FIELD_MTIME, G_LOCAL_FILE_STAT_FIELD_ALL, &final_stat) == 0)
     file->priv->etag = _g_local_file_info_create_etag (&final_stat);
 
   if (!g_close (file->priv->fd, NULL))
@@ -891,12 +896,15 @@ handle_overwrite_open (const char    *filename,
       g_free (display_name);
       return -1;
     }
-  
-#ifdef G_OS_WIN32
-  res = GLIB_PRIVATE_CALL (g_win32_fstat) (fd, &original_stat);
-#else
-  res = fstat (fd, &original_stat);
-#endif
+
+  res = g_local_file_fstat (fd,
+                            G_LOCAL_FILE_STAT_FIELD_TYPE |
+                            G_LOCAL_FILE_STAT_FIELD_MODE |
+                            G_LOCAL_FILE_STAT_FIELD_UID |
+                            G_LOCAL_FILE_STAT_FIELD_GID |
+                            G_LOCAL_FILE_STAT_FIELD_MTIME |
+                            G_LOCAL_FILE_STAT_FIELD_NLINK,
+                            G_LOCAL_FILE_STAT_FIELD_ALL, &original_stat);
   errsv = errno;
 
   if (res != 0)
@@ -911,9 +919,9 @@ handle_overwrite_open (const char    *filename,
     }
   
   /* not a regular file */
-  if (!S_ISREG (original_stat.st_mode))
+  if (!S_ISREG (_g_stat_mode (&original_stat)))
     {
-      if (S_ISDIR (original_stat.st_mode))
+      if (S_ISDIR (_g_stat_mode (&original_stat)))
 	g_set_error_literal (error,
                              G_IO_ERROR,
                              G_IO_ERROR_IS_DIRECTORY,
@@ -953,7 +961,7 @@ handle_overwrite_open (const char    *filename,
    */
   
   if ((flags & G_FILE_CREATE_REPLACE_DESTINATION) ||
-      (!(original_stat.st_nlink > 1) && !is_symlink))
+      (!(_g_stat_nlink (&original_stat) > 1) && !is_symlink))
     {
       char *dirname, *tmp_filename;
       int tmpfd;
@@ -974,10 +982,10 @@ handle_overwrite_open (const char    *filename,
       if ( ! (flags & G_FILE_CREATE_REPLACE_DESTINATION) &&
 	   (
 #ifdef HAVE_FCHOWN
-	    fchown (tmpfd, original_stat.st_uid, original_stat.st_gid) == -1 ||
+	    fchown (tmpfd, _g_stat_uid (&original_stat), _g_stat_gid (&original_stat)) == -1 ||
 #endif
 #ifdef HAVE_FCHMOD
-	    fchmod (tmpfd, original_stat.st_mode & ~S_IFMT) == -1 ||
+	    fchmod (tmpfd, _g_stat_mode (&original_stat) & ~S_IFMT) == -1 ||
 #endif
 	    0
 	    )
@@ -986,16 +994,18 @@ handle_overwrite_open (const char    *filename,
           GLocalFileStat tmp_statbuf;
           int tres;
 
-#ifdef G_OS_WIN32
-          tres = GLIB_PRIVATE_CALL (g_win32_fstat) (tmpfd, &tmp_statbuf);
-#else
-          tres = fstat (tmpfd, &tmp_statbuf);
-#endif
+          tres = g_local_file_fstat (tmpfd,
+                                     G_LOCAL_FILE_STAT_FIELD_TYPE |
+                                     G_LOCAL_FILE_STAT_FIELD_MODE |
+                                     G_LOCAL_FILE_STAT_FIELD_UID |
+                                     G_LOCAL_FILE_STAT_FIELD_GID,
+                                     G_LOCAL_FILE_STAT_FIELD_ALL, &tmp_statbuf);
+
 	  /* Check that we really needed to change something */
 	  if (tres != 0 ||
-	      original_stat.st_uid != tmp_statbuf.st_uid ||
-	      original_stat.st_gid != tmp_statbuf.st_gid ||
-	      original_stat.st_mode != tmp_statbuf.st_mode)
+	      _g_stat_uid (&original_stat) != _g_stat_uid (&tmp_statbuf) ||
+	      _g_stat_gid (&original_stat) != _g_stat_gid (&tmp_statbuf) ||
+	      _g_stat_mode (&original_stat) != _g_stat_mode (&tmp_statbuf))
 	    {
 	      g_close (tmpfd, NULL);
 	      g_unlink (tmp_filename);
@@ -1014,7 +1024,7 @@ handle_overwrite_open (const char    *filename,
   if (create_backup)
     {
 #if defined(HAVE_FCHOWN) && defined(HAVE_FCHMOD)
-      struct stat tmp_statbuf;      
+      GLocalFileStat tmp_statbuf;
 #endif
       char *backup_filename;
       int bfd;
@@ -1033,7 +1043,7 @@ handle_overwrite_open (const char    *filename,
 
       bfd = g_open (backup_filename,
 		    O_WRONLY | O_CREAT | O_EXCL | O_BINARY,
-		    original_stat.st_mode & 0777);
+		    _g_stat_mode (&original_stat) & 0777);
 
       if (bfd == -1)
 	{
@@ -1050,7 +1060,7 @@ handle_overwrite_open (const char    *filename,
        * bits for the group same as the protection bits for
        * others. */
 #if defined(HAVE_FCHOWN) && defined(HAVE_FCHMOD)
-      if (fstat (bfd, &tmp_statbuf) != 0)
+      if (g_local_file_fstat (bfd, G_LOCAL_FILE_STAT_FIELD_GID, G_LOCAL_FILE_STAT_FIELD_ALL, &tmp_statbuf) != 0)
 	{
 	  g_set_error_literal (error,
                                G_IO_ERROR,
@@ -1062,12 +1072,12 @@ handle_overwrite_open (const char    *filename,
 	  goto err_out;
 	}
       
-      if ((original_stat.st_gid != tmp_statbuf.st_gid)  &&
-	  fchown (bfd, (uid_t) -1, original_stat.st_gid) != 0)
+      if ((_g_stat_gid (&original_stat) != _g_stat_gid (&tmp_statbuf))  &&
+	  fchown (bfd, (uid_t) -1, _g_stat_gid (&original_stat)) != 0)
 	{
 	  if (fchmod (bfd,
-		      (original_stat.st_mode & 0707) |
-		      ((original_stat.st_mode & 07) << 3)) != 0)
+		      (_g_stat_mode (&original_stat) & 0707) |
+		      ((_g_stat_mode (&original_stat) & 07) << 3)) != 0)
 	    {
 	      g_set_error_literal (error,
                                    G_IO_ERROR,
