@@ -1,4 +1,7 @@
+#ifndef GLIB_DISABLE_DEPRECATION_WARNINGS
 #define GLIB_DISABLE_DEPRECATION_WARNINGS
+#endif
+
 #include <glib-object.h>
 #include <stdlib.h>
 
